Class: Hash

Inherits:
Object
  • Object
show all
Defined in:
lib/config.rb

Overview

Instance Method Summary collapse

Instance Method Details

#assert_valid_keys(*valid_keys) ⇒ Object

Validate all keys in a hash match *valid_keys, raising ArgumentError on a mismatch.

Note that keys are treated differently than HashWithIndifferentAccess, meaning that string and symbol keys will not match.

{ name: 'Rob', years: '28' }.assert_valid_keys(:name, :age) # => raises "ArgumentError: Unknown key: :years. Valid keys are: :name, :age"
{ name: 'Rob', age: '28' }.assert_valid_keys('name', 'age') # => raises "ArgumentError: Unknown key: :name. Valid keys are: 'name', 'age'"
{ name: 'Rob', age: '28' }.assert_valid_keys(:name, :age)   # => passes, raises nothing


160
161
162
163
164
165
166
167
# File 'lib/config.rb', line 160

def assert_valid_keys(*valid_keys)
  valid_keys.flatten!
  each_key do |k|
    unless valid_keys.include?(k)
      raise ArgumentError, "Unknown key: #{k.inspect}. Valid keys are: #{valid_keys.map(&:inspect).join(', ')}"
    end
  end
end

#deep_stringify_keysObject

Returns a new hash with all keys converted to strings. This includes the keys from the root hash and from all nested hashes and arrays.

hash = { person: { name: 'Rob', age: '28' } }

hash.deep_stringify_keys
# => {"person"=>{"name"=>"Rob", "age"=>"28"}}


196
197
198
# File 'lib/config.rb', line 196

def deep_stringify_keys
  deep_transform_keys(&:to_s)
end

#deep_stringify_keys!Object

Destructively convert all keys to strings. This includes the keys from the root hash and from all nested hashes and arrays.



203
204
205
# File 'lib/config.rb', line 203

def deep_stringify_keys!
  deep_transform_keys!(&:to_s)
end

#deep_symbolize_keysObject

Returns a new hash with all keys converted to symbols, as long as they respond to to_sym. This includes the keys from the root hash and from all nested hashes and arrays.

hash = { 'person' => { 'name' => 'Rob', 'age' => '28' } }

hash.deep_symbolize_keys
# => {:person=>{:name=>"Rob", :age=>"28"}}


215
216
217
218
219
220
221
222
223
# File 'lib/config.rb', line 215

def deep_symbolize_keys
  deep_transform_keys do |key|
    begin
      key.to_sym
    rescue
      key
    end
  end
end

#deep_symbolize_keys!Object

Destructively convert all keys to symbols, as long as they respond to to_sym. This includes the keys from the root hash and from all nested hashes and arrays.



228
229
230
231
232
233
234
235
236
# File 'lib/config.rb', line 228

def deep_symbolize_keys!
  deep_transform_keys! do |key|
    begin
      key.to_sym
    rescue
      key
    end
  end
end

#deep_transform_keys(&block) ⇒ Object

Returns a new hash with all keys converted by the block operation. This includes the keys from the root hash and from all nested hashes and arrays.

hash = { person: { name: 'Rob', age: '28' } }

hash.deep_transform_keys{ |key| key.to_s.upcase }
# => {"PERSON"=>{"NAME"=>"Rob", "AGE"=>"28"}}


177
178
179
# File 'lib/config.rb', line 177

def deep_transform_keys(&block)
  _deep_transform_keys_in_object(self, &block)
end

#deep_transform_keys!(&block) ⇒ Object

Destructively convert all keys by using the block operation. This includes the keys from the root hash and from all nested hashes and arrays.



184
185
186
# File 'lib/config.rb', line 184

def deep_transform_keys!(&block)
  _deep_transform_keys_in_object!(self, &block)
end

#stringify_keysObject

Returns a new hash with all keys converted to strings.

hash = { name: 'Rob', age: '28' }

hash.stringify_keys
# => {"name"=>"Rob", "age"=>"28"}


110
111
112
# File 'lib/config.rb', line 110

def stringify_keys
  transform_keys(&:to_s)
end

#stringify_keys!Object

Destructively convert all keys to strings. Same as stringify_keys, but modifies self.



116
117
118
# File 'lib/config.rb', line 116

def stringify_keys!
  transform_keys!(&:to_s)
end

#symbolize_keysObject Also known as: to_options

Returns a new hash with all keys converted to symbols, as long as they respond to to_sym.

hash = { 'name' => 'Rob', 'age' => '28' }

hash.symbolize_keys
# => {:name=>"Rob", :age=>"28"}


127
128
129
130
131
132
133
134
135
# File 'lib/config.rb', line 127

def symbolize_keys
  transform_keys do |key|
    begin
      key.to_sym
    rescue
      key
    end
  end
end

#symbolize_keys!Object Also known as: to_options!

Destructively convert all keys to symbols, as long as they respond to to_sym. Same as symbolize_keys, but modifies self.



140
141
142
143
144
145
146
147
148
# File 'lib/config.rb', line 140

def symbolize_keys!
  transform_keys! do |key|
    begin
      key.to_sym
    rescue
      key
    end
  end
end

#transform_keysObject

Returns a new hash with all keys converted using the block operation.

hash = { name: 'Rob', age: '28' }

hash.transform_keys{ |key| key.to_s.upcase }
# => {"NAME"=>"Rob", "AGE"=>"28"}


85
86
87
88
89
90
91
92
# File 'lib/config.rb', line 85

def transform_keys
  return enum_for(:transform_keys) unless block_given?
  result = self.class.new
  each_key do |key|
    result[yield(key)] = self[key]
  end
  result
end

#transform_keys!Object

Destructively convert all keys using the block operations. Same as transform_keys but modifies self.



96
97
98
99
100
101
102
# File 'lib/config.rb', line 96

def transform_keys!
  return enum_for(:transform_keys!) unless block_given?
  keys.each do |key|
    self[yield(key)] = delete(key)
  end
  self
end